Money class

Constructors

Money.inrPaise(int paise)
factory
Money.inrRupees(int rupees)
factory

Properties

amount int
final
asDouble double
no setter
currency String
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator *(int multiplier) Money
operator +(Money other) Money
operator ==(Object other) bool
The equality operator.
override

Static Methods

zero({String currency = 'INR'}) Money