Order class

Constructors

Order({required String orderId, required String customerId, required List<OrderItem> items, Subscription? subscription, required TimeSlot timeSlot, required DateTime createdAt})

Properties

createdAt DateTime
final
customerId String
final
hashCode int
The hash code for this object.
no setterinherited
items List<OrderItem>
final
loyaltyApplied bool
no setter
orderId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status OrderStatus
no setter
subscription Subscription?
final
timeSlot TimeSlot
final
totalAmount Money
no setter

Methods

canBeCancelled() → void
cancel() → void
complete() → void
confirm() → void
markDelivered() → void
markLoyaltyApplied() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited