OrderItem class
Constructors
- OrderItem({required String productId, required ProductType productType, required double quantity, required ProductUnit unit, required Money unitPrice})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- productId → String
-
final
- productType → ProductType
-
final
- quantity → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalPrice → Money
-
no setter
- unit → ProductUnit
-
final
- unitPrice → Money
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override