Subscription class

Constructors

Subscription({required String subscriptionId, required String customerId, required DateTime startDate, DateTime? endDate, required TimeSlot deliverSlot, required int quantityPerDay, required String unit})

Properties

cancelledAt DateTime?
getter/setter pair
customerId String
final
deliverSlot TimeSlot
final
endDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
pausedAt DateTime?
getter/setter pair
quantityPerDay int
final
resumeAt DateTime?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime
final
status SubscriptionStatus
no setter
subscriptionId String
final
unit String
final

Methods

cancel() → void
isActiveOn(DateTime date) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
resume() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited