TimeSlot class

Constructors

TimeSlot({required int startHour, required int startMinute, required int endHour, required int endMinute})
const

Properties

endHour int
final
endMinute int
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startHour int
final
startMinute int
final

Methods

contains(int hour, int minute) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override