InventoryPort class abstract

Inventory Port Role

  1. Order place krne se pahle -> Stock check
  2. Order krte time -> stock reserve
  3. Order cancel hone pe -> stock release That's it Iske alawa kuch nahi.

Constructors

InventoryPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isAvailable({required String productId, required double quantity}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release({required String productId, required double quantity, required String orderId}) → void
reserve({required String productId, required double quantity, required String orderId}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited