OrderService class

Constructors

OrderService({required InventoryPort inventoryPort, required LoyaltyPort loyaltyPort, required OrderRepository orderRepository, required PricingPort pricingPort})

Properties

hashCode int
The hash code for this object.
no setterinherited
inventoryPort InventoryPort
final
loyaltyPort LoyaltyPort
final
orderRepository OrderRepository
final
pricingPort PricingPort
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelOrder(String orderId) → void
completedOrder(String orderId) → void
confirmOrder(String orderId) → void
createOrder({required String customerId, required List<OrderItemRequest> items, Subscription? subscription, required TimeSlot timeSlot}) Order
markDelivered(String orderId) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited